/// <summary>
///     Table Toggle Functions </summary>
/// <remarks>
/// <version>1.1</verion>
/// <created>   <date>12 Aug 2003</date> 
///             <author> John Bentley  </author> </created><br />  
/// </remarks>

function getErrorObj(msg) {
  var err = new Error(msg);
  err.name = "myError";
  return err;
}


/// <summary>   
///     Shows or Hides the rows of the table in tbody. </summary>        
/// <param name="theadElement"> 
///     That part of the table designated as a thead.
///      </param>
/// <remarks> 
///     To make a table collapsable.
///     1. Ensure there are thead and tbody sections.
///     2. Add "collapsable" as a class to the tbody element
///        (you can have multiple classes).
///     3. Add code to call this function from the onclick event
///         of the thead.
///     4. Add mouse event commands to active the .commandMouseOver style.
///          
/// <example>
/// <newpara>
///     Use like this:</newpara>
///       Whack this in your stylesheet:
///       .commandMouseOver    
///       {    
///           /* Pointer Hack. Hand must come last otherwise WinIE5.x chokes */    
///           cursor: pointer;    
///           cursor: hand;    
///           /* End Hack */    
///               
///           border: solid 1px #ff4500;    
///           background-color: #ffa500;    
///       }    
///           
///       tbody.collapsable    
///       {
///           display: none;    
///       }    
///
////// <newpara><code> 
//////     <thead id="theadMine"  
///            onclick="return toggleTableBodyDisplay(this);" 
///            onmouseover="this.className='commandMouseOver';" 
///            onmouseout="this.className='';">
///        ..
///         <tbody class="collapsable" ..>
/// </code></newpara>
/// </example>
/// <created>   <date>12 Aug 2003</date> 
///             <author> John Bentley </author> </created><br />
/// </remarks>
function toggleTableBodyDisplay(theadElement) {
  var tbodyElement = theadElement.parentNode.tBodies[0]
  
  // Toggle the <tbody></tbody> display.
  // Use table-header-group as table-body-group doesn't work
  if (tbodyElement.style.display == "table-header-group") {
    tbodyElement.style.display = "none";
  } else {
    tbodyElement.style.display = "table-header-group";
  }

}

function tableBodyHide(table) {
  var tbodyElement = table.tBodies[0]
  
  tbodyElement.style.display = "none";
}

function tableBodyShow(table) {
  var tbodyElement = table.tBodies[0]
  
  tbodyElement.style.display = "table-header-group";
}


// Summary: Expands or Collapses all tbodys belonging to the class "collapsable".
// Remarks: Works on all tables in the document
//          with a tbody class in 'collapsable'.
//          Handles multiple classes correctly.
//          eg if we have '<tbody class="myClass collapsable" ...'
//          then the table body still collpases.
// Params:
//    action: either 'collapse' or 'expand'
//    doc: the document object of the web page.
// Example:
//          expandOrCollapseTBodies('expand', document);
// Created: by John Bentley 30 Jul 2004.
function expandOrCollapseTbodies(action, doc){
  var tables = doc.getElementsByTagName("table");
  var msg = "";
  var strClass = "";
  var isCollapsable;
  
  try {

    if (action != 'expand' && action != 'collapse') {
        throw getErrorObj("action is '" + action + "' but should be 'expand' or 'collapse'");
    }
    for (var i = 0; i < tables.length; i ++) {
      strClass = tables[i].tBodies[0].className;
      
      // Does the body belong to the "collapsable" class.
      // We need to do it this way as there might be more than one class
      // in the class attribute. eg <tbody class="someClass collapsable">
      isCollapsable = strClass.indexOf("collapsable") > -1 ? true : false;
      if (isCollapsable && action == 'expand') {
        tableBodyShow(tables[i]);
      } else if (isCollapsable && action == 'collapse') {
        tableBodyHide(tables[i]);
      }
      //msg += "table " + i + ": " + strClass  + " IsCollapsable: " + isCollapsable + "\n";
    }
    //window.alert(msg);
  
  } catch (e) {
    switch (e.name) {
      case "myError":
        
        msg = "The Developer of this page did not think of this circumstance: \n";
        msg += "He, being John Bentley, probably tried to pass in incorrect arg to expandOrCollapseTbodies(..) \n";
        msg += "Details: Error Name - " + e.name + "; Error String - " + e.toString();
        msg += "\n If you can just ignore the error. ";
        
        alert(msg);
        break;
      default:
        alert("Unhandled Exception: " + e.name);
    }
    return false;
  } finally {
    // Executes no matter what.
  }
  // Executes if exception not thrown.
  return true;        
}
