/// <summary> A library of EcmaScript Date/Time Functions
/// </summary>
/// <source>EcmaScriptLibary\dateTime.js</source>
/// <created>   <date>12 Aug 2003</date> 
///             <author> John Bentley  </author> </created><br />  

// Summary: A centralised error handler
function handleError(exn) {
  WScript.Echo("Exception: " + exn.toString());
}
/// <summary>   
///     Ensures that numbers are returned as two digits with a 
///     leading zero if necessary. </summary>        
/// <returns>   
///      </returns>
/// <created>   <date>12 Aug 2003</date> 
///             <author> John Bentley </author> </created><br />
function formatLeadingZero(number){
 try {
  if(number.toString().length > 2) {
    throw "number passed must be less than 2 digits";
  }
  if(number.toString().length == 1) {
    return "0" + number;
  } else {
    return number.toString();
  }
 }
 catch (exn) {
  HandleError(exn);
 }
 
}

// Returns: the TimeZone offset to Local to get UTC, in minutes,
//          converted HHMM you need to apply to UTC to get back to the Local time.
// Remarks: So the sign of the minutes is swapped. 
// Example: getMinutesAsHoursMinutes(-570) => +09:30
function getOffsetAsHoursMinutes(minutes) {
  var floatHours = Math.abs(minutes) / 60;
  var strHours = formatLeadingZero(parseInt(floatHours));
  var floatFraction = Math.abs(floatHours) - parseInt(floatHours);
  var intMinutes = floatFraction * 60;
  var strMinutes = formatLeadingZero(intMinutes);
  
  var strSign = (minutes >= 0) ? "-" : "+"
  return strSign + strHours + strMinutes;
}

// Returns: the date and time in YYYYMMDD_HHNN format.
function getDateTimeFile(theDate) {
  var result = "";
  result += theDate.getFullYear();
  result += formatLeadingZero(theDate.getMonth() + 1);
  result += formatLeadingZero(theDate.getDate());
  result += "_"
  result += formatLeadingZero(theDate.getHours());
  result += formatLeadingZero(theDate.getMinutes());
  return result;
}

// Returns: the date and time in YYYY-MM-DDTHH:MM:SS format
function getDateTimeIso(theDate) {
  var result = "";
  result += theDate.getFullYear();
  result += "-"
  result += formatLeadingZero(theDate.getMonth() + 1);
  result += "-"
  result += formatLeadingZero(theDate.getDate());
  result += "T"
  result += formatLeadingZero(theDate.getHours());
  result += ":"
  result += formatLeadingZero(theDate.getMinutes());
  result += ":"
  result += formatLeadingZero(theDate.getSeconds());
  return result;
}

// Returns: the date and time in a format that is safe for use
//          in XSL stylesheets. Ie, YYYYMMDDHHNNSS
function getDateTimeXslSafe(theDate) {
  var result = "";
  
  result += theDate.getFullYear();
  result += formatLeadingZero(theDate.getMonth() + 1);
  result += formatLeadingZero(theDate.getDate());
  result += formatLeadingZero(theDate.getHours());
  result += formatLeadingZero(theDate.getMinutes());
  result += formatLeadingZero(theDate.getSeconds());
  return result; 
 
}

// Returns: the local date and time in a user readable format.
// Example: Fri, 18 Jun 2004 14:44 AUS Eastern Standard Time (UTC+1000)
// Remarks: Its a bit of a hack as it only shows the full timezone-operating-under
//          For Eastern Australia (NSW, VIC, etc).
//          But if the time zone is different it just omits this timezone-operating-under
//          eg Fri, 18 Jun 2004 14:44 (UTC+0500)
function getDateTimeLocalFriendly(theDate) {
 var monthNames = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
 var dayNames = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
 
 var theYear = theDate.getFullYear();
 var theMonth = monthNames[theDate.getMonth()];
 var theDay = dayNames[theDate.getDay()];
 var theDayInMonth = formatLeadingZero(theDate.getDate());
 var theHours = formatLeadingZero(theDate.getHours());
 var theMinutes = formatLeadingZero(theDate.getMinutes());
 
 var theTimezoneOperatingUnder = "";
  switch (theDate.getTimezoneOffset()) {
  case -600:
    theTimezoneOperatingUnder = " AUS Eastern Standard Time ";
    break;
  case -660:
    theTimezoneOperatingUnder = " AUS Eastern Daylight Time ";
    break;
  default:
    theTimezoneOperatingUnder = " ";
 }
 
 var theTimezoneOffsetString = "(UTC" + getOffsetAsHoursMinutes(theDate.getTimezoneOffset()) + ")";
 var result = "";
 
 result += theDay + ", " + theDayInMonth + " " + theMonth + " " + theYear;
 result += " " + theHours + ":" + theMinutes;
 result += theTimezoneOperatingUnder + theTimezoneOffsetString;
 
 return result;
}

/*
 * DateFormat.js
 * Formats a Date object into a human-readable string
 *
 * Copyright (C) 2001 David A. Lindquist (http://www.gazingus.org)
 */
 
 /* Modifications:
      Have been made to the Format Mask characters to conform to the code
      under Visual Studio.net 2002.
      
    Modified By:
      John Bentley
    
    Usage Modified from: 
      http://www.gazingus.org/html/Date_Formatting_Function.html
    
    Usage:
      The single method format extends the native Date class. 
      It takes a string argument representing a "mask" to apply the date object, 
      resulting in a human-readable string. Given a Date object now, the following statements:

      now.format("MM/dd/yy");
      now.format("d MMMM yyyy h:mm:ss tt");
      now.format("dddd, MMMM D");        
      now.format();

      would evaluate to, respectively:

      08/28/05
      28 August 2005 1:40:46 PM
      Sunday, August 28th
      28-Aug-05

      As the last example shows, if no mask is supplied the method uses a default mask. 
      The mask elements are replaced with their corresponding values, while non-mask characters 
      are preserved. Recognized mask elements and their values are as follows:

      d       day of the month
      D       day of the month with suffix
      dd      day of the month, leading zero
      ddd     day of the week, abbreviated
      dddd    day of the week, full
      M       month number
      MM      month number, leading zero
      MMM     month name, abbreviated
      MMMM    month name, full
      y       year, last digit
      yy      year, last two digits
      yyyy    year, four digits
      h       hour (12-hour)
      hh      hour, leading zero (12-hour)
      H       hour (24-hour)
      HH      hour, leading zero (24-hour)      
      m       minute
      mm      minute, leading zero
      s       second
      ss      second, leading zero
      t       meridian, one character
      tt      meridian, two characters

      The script can be customized for other languages by altering the three global 
      variables Date.MONTHS, Date.DAYS, and Date.SUFFIXES. 
*/

Date.MONTHS = [
  'January', 'February', 'March', 'April', 'May', 'June', 'July',
  'August', 'September', 'October', 'November', 'December'
];

Date.DAYS = [
  'Sunday', 'Monday', 'Tuesday', 'Wednesday',
  'Thursday', 'Friday', 'Saturday'
];

Date.SUFFIXES = [
  'st','nd','rd','th','th','th','th','th','th','th',
  'th','th','th','th','th','th','th','th','th','th',
  'st','nd','rd','th','th','th','th','th','th','th',
  'st'
];

Date.prototype.format = function( mask ) {
  var formatted     = ( mask != null ) ? mask : 'dd-MMM-yyyy';
  var letters       = 'DMHdyhmst'.split( '' );
  var temp          = new Array();
  var count         = 0;
  var regexA;
  var regexB        = /\[(\d+)\]/;

  var day           = this.getDay();
  var date          = this.getDate();
  var month         = this.getMonth();
  var year          = this.getFullYear().toString();
  var hours         = this.getHours();
  var minutes       = this.getMinutes();
  var seconds       = this.getSeconds();

  var formats       = new Object();
  formats[ 'd' ]    = date;
  formats[ 'D' ]    = date + Date.SUFFIXES[ date - 1 ];
  formats[ 'dd' ]   = ( date < 10 ) ? '0' + date : date;
  formats[ 'ddd' ]  = Date.DAYS[ day ].substring( 0, 3 );
  formats[ 'dddd' ] = Date.DAYS[ day ];
  formats[ 'M' ]    = month + 1;
  formats[ 'MM' ]   = ( month + 1 < 10 ) ? '0' + ( month + 1 ) : month + 1;
  formats[ 'MMM' ]  = Date.MONTHS[ month ].substring( 0, 3 );
  formats[ 'MMMM' ] = Date.MONTHS[ month ];
  formats[ 'y' ]    = ( year.charAt( 2 ) == '0' ) ? year.charAt( 3 ) : year.substring( 2, 4 );
  formats[ 'yy' ]   = year.substring( 2, 4 );
  formats[ 'yyyy' ] = year;
  formats[ 'H' ]    = hours;
  formats[ 'HH' ]   = ( hours < 10 ) ? '0' + hours : hours;  
  formats[ 'h' ]    = ( hours > 12 || hours == 0 ) ? Math.abs( hours - 12 ) : hours;
  formats[ 'hh' ]   = ( formats[ 'h' ] < 10 ) ? '0' + formats[ 'h' ] : formats[ 'h' ];
  formats[ 'm' ]    = minutes;
  formats[ 'mm' ]   = ( minutes < 10 ) ? '0' + minutes : minutes;
  formats[ 's' ]    = seconds;
  formats[ 'ss' ]   = ( seconds < 10 ) ? '0' + seconds : seconds;
  formats[ 't' ]    = ( hours < 12 ) ?  'A' : 'P';
  formats[ 'tt' ]   = ( hours < 12 ) ?  'AM' : 'PM';

  for ( var i = 0; i < letters.length; i++ ) {
    regexA = new RegExp( '(' + letters[ i ] + '+)' );
    while ( regexA.test( formatted ) ) {
      temp[ count ] = RegExp.$1;
      formatted = formatted.replace( RegExp.$1, '[' + count + ']' );
      count++;
    }
  }

  while ( regexB.test( formatted ) ) {
    formatted = formatted.replace( regexB, formats[ temp[ RegExp.$1 ] ] );
  }

  return formatted;
}
