<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml"
  version="1.0"
>
  <!-- xwmToXhtml.xslt Version: 2.3 -->
  <!-- 
  Summary: Identity Transform any XML or XHTML file to an XHTML 1.1 file,
           allowing specific handling for particular elements.
  Handles: Elements and attributes from any Namespace.
  LeavesOut:
           Processing Instructions.
-->
  <!-- 
       Explicitly output DOCTYPE Declarations, and XML declaration elsewhere in this
       Sytlesheet to avoid bugs and help with output formatting.
        
       MSXML4.0: Use xml method for xhtml output as this correctyl preserves empty tags,
       like <br /> that are in this XSLT stylesheet. A "html" method doesn't do
       this.
       
       The destination file extension must be then controlled by the transforming program.
       So TransformDir.wsf, for example, gives the option to overide the destination file
       extension. 
       
  -->
  <!-- Being the immediate child of stylesheet this variable has global scope -->
  <xsl:variable name="directoryLevel" xml:space="no">
    <xsl:choose>
      <xsl:when test="//*[local-name()='subDirectoryFlag']">../</xsl:when>
      <xsl:otherwise></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
   
  <!-- Needed to allow the subDirectoryFlag in the source doc -->
  <xsl:template match="*[local-name()='subDirectoryFlag']" xml:space="preserve">
  </xsl:template>
    
  <xsl:output method="xml" omit-xml-declaration="yes" />
  
  <xsl:param name="nowLocalFriendly">Wed, 16 Jun 1999 11:02 (+1000 AUS Eastern Standard Time)</xsl:param>
  
  <!--  This template rule is for debugging.
        It catches elements that have not yet had a specific template rule applied.
        Run your mouse over the yellow background and observe the Tooltip -->
  <xsl:template match="*">
    <span style="background-color:yellow">
      <xsl:attribute name="title">Warning... &lt; 
      <xsl:value-of select="name()" />&gt; 
      <xsl:value-of select="." />
      <br />&lt; 
      <xsl:value-of select="name()" />&gt; ... does not match a specific
      template_rule in the xslt stylesheet.</xsl:attribute>
      <xsl:apply-templates />
    </span>
  </xsl:template>
 
  <!-- Match: Stuff in the prologue, before the root element (html). 
              That is, comments, etc 
       Do:    Ensure each node gets its own line. -->
  <xsl:template match="/comment()">
    <xsl:choose>
      <!-- Leave 'OnlyInSource' type comments in the source docuemnt -->
      <xsl:when test="contains(.,'OnlyInSource:')"></xsl:when>
      <xsl:otherwise>
        <xsl:text></xsl:text><xsl:copy>&#10;</xsl:copy>
      </xsl:otherwise>
    </xsl:choose>    
  </xsl:template>
  
  <!-- Match: Match: The document root (not the root element)  -->     
  <xsl:template match="/">
    <!-- Keep the closing text tag, </xsl:text>, indented flush for output formatting -->
    <xsl:text disable-output-escaping="yes">&lt;!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd"&gt;
</xsl:text>
    <xsl:copy>
      <xsl:apply-templates select="*|comment()"/>
    </xsl:copy>
  </xsl:template>
  
<!--  Summary:   Identity transformation 
          Remarks:
                Inserts only the namespace prefix definitions that are needed
                at the highest element. Somehow.
                So any user or extension namespace not actually used in the
                resulting transformation is dropped. 
-->
    <xsl:template match="*">
      <xsl:element name="{name(.)}" >
        <xsl:for-each select="@*">
            <xsl:attribute name="{name(.)}" >
                  <xsl:value-of select="."/>
            </xsl:attribute>
        </xsl:for-each>
        <xsl:apply-templates/>
      </xsl:element>
    </xsl:template>


  <!-- 
       Match:   Elements with empty content, explicitly named,
                and regardles of their namespace. 
       Summary: Output each matched element as an empty tagged element
                of form
                
                  <elementname [attributename="value"]+ /> 
                  
                That is, a singled tagged empty element.
                
       Remarks: 
                Outputs a space before closing backslash and 
                  bracket ( /> ).
                Element and attribute name will include a 
                  namespace prefix if any.
                We explicitly name the links we want to be empty
                  so we don't turn deliberate two tagged empty
                  elements into single tagged ones. Eg we DONT
                  want <script ></script> to turn into <script />

       Example Output: 
                <br /> 
                <meta name="author" content="John Bentley" /> 
                <cool:myEmptyTag cool:feeling="nice" />
  -->  
  
    <xsl:template match=
                      "*[local-name()='br'] 
                     | *[local-name()='meta']
                     | *[local-name()='link']
                     | *[local-name()='img']  
                     | *[local-name()='col']">
    <xsl:text disable-output-escaping="yes">&lt;</xsl:text>
    <xsl:value-of select="name(.)" />
    <xsl:for-each select="@*" >
      <xsl:text> </xsl:text>
      <xsl:value-of select="name(.)" />="<xsl:value-of select="."/>"</xsl:for-each>
    <xsl:text disable-output-escaping="yes"> /&gt;</xsl:text>
  </xsl:template>
  
  <!-- Script without a src, that is, inline scripting -->
  <xsl:template match="*[local-name()='script'][not(@src)]" xml:space="preserve">
  <script type="text/javascript">
  <xsl:text disable-output-escaping="yes">/* &lt;![CDATA[ */</xsl:text>
    <xsl:value-of select="." disable-output-escaping="yes" />
  <xsl:text disable-output-escaping="yes">/* ]]&gt; */</xsl:text>
  </script>
  </xsl:template>  
    
  <!-- *********** Website specific bellow here ******************** -->
  <xsl:template match="comment()">
    <xsl:choose>
      <!-- Leave 'OnlyInSource' type comments in the source docuemnt -->
      <xsl:when test="contains(.,'OnlyInSource:')"></xsl:when>
      <xsl:otherwise>
        <xsl:comment>
          <xsl:value-of select="." />
        </xsl:comment>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="*[local-name()='commonHead']" xml:space="preserve">
    <xsl:comment> Common head start </xsl:comment>
    <xsl:comment>
    Omit XML declaration from top line as it puts IE6 in quirks mode.
    Since the XML declaration is omitted ensure your pages are encoded in UTF-8 
    (or UTF-16) to conform to XML (a requirement of XTHML)   
    </xsl:comment>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />

    <meta name="keywords" content="philosophy discussion meeting forum discuss talk free speech spoken word open" />  
    <meta name="author" content="John Bentley" />
    <meta name="generator" content="John Bentley's XsltWebMaker." />
    <!-- Search Engine Activity -->
    <meta name="robots" content="index,follow" />
    <meta name="revisit-after" content="30 days" />
    
    <meta http-equiv="content-script-type" content="text/javascript" />
   
    <xsl:comment> Note the following line enables intellisense in Visual Studio .NET </xsl:comment>
    <meta name="vs_targetSchema" content="http://schemas.microsoft.com/intellisense/ie5" /> 
    
    <script type="text/javascript">
    <xsl:text disable-output-escaping="yes">/* &lt;![CDATA[ */  
    </xsl:text>    
    <!-- Script here -->
    <xsl:text disable-output-escaping="yes">/* ]]&gt; */  
    </xsl:text>      
    </script>    
     
    <xsl:comment> Common head Finish </xsl:comment>
  </xsl:template>
  
  <xsl:template match="*[local-name()='directoryDependantHead']" xml:space="preserve">
    <xsl:comment> directoryDependantHead start </xsl:comment>
    <link type="text/css" rel="stylesheet" href="{concat($directoryLevel, 'minimalist.css')}" />
    <script type="text/javascript" src="{concat($directoryLevel, 'webDateTime.js')}"></script>  
    <xsl:comment> directoryDependantHead Finish </xsl:comment>
  </xsl:template>    

  <xsl:template match="*[local-name()='speechHead']" xml:space="preserve">
    <xsl:comment> speechHead head start </xsl:comment>
    <link type="text/css" rel="stylesheet" href="speech.css" />
    <xsl:comment> speechHead head Finish </xsl:comment>
  </xsl:template>     
   
  <!-- Make a match whether the element belongs to a namespace
       or belongs to no namespace -->
  <xsl:template match="*[local-name()='navigation']" xml:space="preserve">
    <div id="navigation">
      <ul>
        <li><a href="{concat($directoryLevel, 'index.html')}">Home</a></li> 
        <li><a href="{concat($directoryLevel, 'examplePlainPage.html')}">Example Plain Page</a></li> 
        <li>Meetings
          <ul>
            <li><a href="{concat($directoryLevel, 'meetingsPast.html')}">Past</a></li>
            <li><a href="{concat($directoryLevel, 'meetingsFuture.html')}">Future</a></li>
          </ul>
        </li>
      </ul>           
    </div>

    </xsl:template> <!-- </xsl:template> here to reduce new lines in output -->
      
  <xsl:template match="*[local-name()='validators']" xml:space="preserve">
    <div id="validators">
      <a href="http://validator.w3.org/check?uri=referer">
        <img src="http://www.w3.org/Icons/valid-xhtml11"
             alt="Valid XHTML 1.1!" />
      </a>
    </div></xsl:template> <!-- </xsl:template> here to reduce new lines in output -->
  
  <xsl:template match="*[local-name()='pageTitleSource']" >
      <xsl:value-of select="." /> 
  </xsl:template>
    
  <xsl:template match="*[local-name()='topArea']" xml:space="preserve">
    <div id="topArea">
      <div id="logo">
         <a href="{concat($directoryLevel, 'index.html')}">
          <span id="siteName">
            XslWebMaker
          </span>
          <span id="slogan" class="introduction">
            A website from XML files
          </span>
        </a>
      </div>
      
      <div id="pageTitle" class="introduction">
        <xsl:value-of select="//*[local-name()='pageTitleSource']" /> 
      </div>
      <div style="clear:both"> </div>      
    </div></xsl:template> <!-- </xsl:template> here to reduce new lines in output -->  

    <xsl:template match="*[local-name()='footer']" >

    <div id="websiteLastUpdated">
      Page updated: <xsl:value-of select="$nowLocalFriendly" />; 
      XslWebMaker Version: 3.04
    </div></xsl:template>  <!-- </xsl:template> here to reduce new lines in output -->
</xsl:stylesheet>
